@@ -1,6 +1,6 @@
 package Mojo::Webqq;
 use strict;
-$Mojo::Webqq::VERSION = "1.5.9";
+$Mojo::Webqq::VERSION = "1.6.0";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -52,12 +52,13 @@ has log    => sub{Mojo::Webqq::Log->new(encoding=>$_[0]->log_encoding,path=>$_[0
     }
     @lines = split /\n/,join "",@lines;
     my $return = "";
-    $time = POSIX::strftime('[%y/%m/%d %H:%M:%S]',localtime($time));
+    $time = $time?POSIX::strftime('[%y/%m/%d %H:%M:%S]',localtime($time)):"";
+    $level = $level?"[$level]":"";
     for(@lines){
         $return .=
-            $time
-        .   " " 
-        .   "[$level]" 
+          $time
+        . " " 
+        . $level 
         . " " 
         . $title 
         . $_ 
